diff --git a/product/ERP5/tests/testXHTML.py b/product/ERP5/tests/testXHTML.py
index edc4200b20aa0c80312c0b7160fede02b1e8b9ce..a32a93448bf118abf8af0e01eb67b3b4670ea3f7 100644
--- a/product/ERP5/tests/testXHTML.py
+++ b/product/ERP5/tests/testXHTML.py
@@ -160,10 +160,10 @@ class TestXHTML(ERP5TypeTestCase):
                   obj_metatypes=['ProxyField'], search_sub=1):
           template_field = field.getTemplateField(cache=False)
           if template_field is None:
             # Base_viewRelatedObjectListBase (used for proxy listbox ids on
             # relation fields) is an exception, the proxy field has no target
             # by default.
-            if field_path != 'Base_viewRelatedObjectListBase/listbox':
+            if field_path != 'Base_viewRelatedObjectList/listbox':
               error_list.append((skin_name, field_path, field.get_value('form_id'),
                                  field.get_value('field_id')))
@@ -160,10 +160,10 @@ class TestXHTML(ERP5TypeTestCase):
           template_field = field.getTemplateField(cache=False)
           if template_field is None:
-            # Base_viewRelatedObjectListBase (used for proxy listbox ids on
+            # Base_viewRelatedObjectList (used for proxy listbox ids on
             # relation fields) is an exception, the proxy field has no target
             # by default.